@@ -17,7 +17,10 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gspell-navigator-text-view.h"
 #include <glib/gi18n-lib.h>
 #include "gspell-text-buffer.h"
@@ -305,7 +308,7 @@ gspell_navigator_text_view_goto_next (GspellNavigator  *navigator,
 			     GSPELL_CHECKER_ERROR_NO_LANGUAGE_SET,
 			     "%s",
 			     _("Spell checker error: no language set. "
-			       "It's maybe because no dictionaries are installed."));
+			       "It’s maybe because no dictionaries are installed."));
 
 		return FALSE;
 	}
