@@ -1,7 +1,7 @@
 /*
  * This file is part of gspell, a spell-checking library.
  *
- * Copyright 2015 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2015, 2016 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,22 +17,25 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GSPELL_NAVIGATOR_H__
-#define __GSPELL_NAVIGATOR_H__
+#ifndef GSPELL_NAVIGATOR_H
+#define GSPELL_NAVIGATOR_H
 
-#if !defined (__GSPELL_H_INSIDE__) && !defined (GSPELL_COMPILATION)
+#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
 #error "Only <gspell/gspell.h> can be included directly."
 #endif
 
 #include <glib-object.h>
 #include <gspell/gspell-checker.h>
+#include <gspell/gspell-version.h>
 
 G_BEGIN_DECLS
 
 #define GSPELL_TYPE_NAVIGATOR (gspell_navigator_get_type ())
+
+GSPELL_AVAILABLE_IN_ALL
 G_DECLARE_INTERFACE (GspellNavigator, gspell_navigator,
 		     GSPELL, NAVIGATOR,
-		     GObject)
+		     GInitiallyUnowned)
 
 struct _GspellNavigatorInterface
 {
@@ -52,21 +55,24 @@ struct _GspellNavigatorInterface
 						 const gchar     *change_to);
 };
 
+GSPELL_AVAILABLE_IN_ALL
 gboolean	gspell_navigator_goto_next	(GspellNavigator  *navigator,
 						 gchar           **word,
 						 GspellChecker   **spell_checker,
 						 GError          **error);
 
+GSPELL_AVAILABLE_IN_ALL
 void		gspell_navigator_change		(GspellNavigator *navigator,
 						 const gchar     *word,
 						 const gchar     *change_to);
 
+GSPELL_AVAILABLE_IN_ALL
 void		gspell_navigator_change_all	(GspellNavigator *navigator,
 						 const gchar     *word,
 						 const gchar     *change_to);
 
 G_END_DECLS
 
-#endif /* __GSPELL_NAVIGATOR_H__ */
+#endif /* GSPELL_NAVIGATOR_H */
 
 /* ex:set ts=8 noet: */
